@@ -1,12 +1,14 @@
-#' @title BMisc
-#'
-#' @description A set of miscellaneous helper functions
-#'
-#' @docType package
 #' @name BMisc
+#' @title BMisc
+#' @description A set of miscellaneous helper functions
+#' @keywords internal
 #' @useDynLib BMisc
 #' @importFrom Rcpp sourceCpp
 #' @import graphics
 #' @import stats
-#' @importFrom dplyr group_by mutate %>% group_map
+#' @importFrom dplyr group_by mutate %>% group_map select starts_with
+#' @importFrom tidyr pivot_wider
+#' @importFrom caret findLinearCombos
+"_PACKAGE"
+
 NULL
